@@ -7,12 +7,12 @@ from typing import Iterator
 
 import pytest
 from markdown_it.token import Token
-from rich.style import Style
 from rich.text import Span
 
 import textual.widgets._markdown as MD
 from textual import on
 from textual.app import App, ComposeResult
+from textual.style import Style
 from textual.widget import Widget
 from textual.widgets import Markdown
 from textual.widgets.markdown import MarkdownBlock
@@ -90,6 +90,7 @@ async def test_markdown_nodes(
             yield from markdown_nodes(node)
 
     async with MarkdownApp(document).run_test() as pilot:
+        await pilot.pause()
         assert [
             node.__class__ for node in markdown_nodes(pilot.app.query_one(Markdown))
         ] == expected_nodes
@@ -107,16 +108,15 @@ URL](https://example.com)\
         markdown = pilot.app.query_one(Markdown)
         paragraph = markdown.children[0]
         assert isinstance(paragraph, MD.MarkdownParagraph)
-        assert paragraph._text.plain == "My site has this URL"
-        expected_spans = [
-            Span(8, 11, Style(meta={"@click": "link('https://example.com')"})),
-            Span(11, 12, Style(meta={"@click": "link('https://example.com')"})),
-            Span(12, 16, Style(meta={"@click": "link('https://example.com')"})),
-            Span(16, 17, Style(meta={"@click": "link('https://example.com')"})),
-            Span(17, 20, Style(meta={"@click": "link('https://example.com')"})),
-        ]
+        assert paragraph._content.plain == "My site has this URL"
+        print(paragraph._content.spans)
 
-    assert paragraph._text.spans == expected_spans
+        expected_spans = [
+            Span(8, 20, Style.from_meta({"@click": "link('https://example.com')"})),
+        ]
+        print(expected_spans)
+
+    assert paragraph._content.spans == expected_spans
 
 
 async def test_load_non_existing_file() -> None:
@@ -160,6 +160,7 @@ async def test_update_of_document_posts_table_of_content_update_message() -> Non
             messages.append(event.__class__.__name__)
 
     async with TableOfContentApp().run_test() as pilot:
+
         assert messages == ["TableOfContentsUpdated"]
         await pilot.app.query_one(Markdown).update("")
         await pilot.pause()
@@ -195,7 +196,8 @@ async def test_link_in_markdown_table_posts_message_when_clicked():
 
     app = MarkdownTableApp()
     async with app.run_test() as pilot:
-        await pilot.click(Markdown, offset=(3, 3))
+        await pilot.click(Markdown, offset=(8, 3))
+        print(app.messages)
         assert app.messages == ["LinkClicked"]
 
 
@@ -213,5 +215,5 @@ async def test_markdown_quoting():
 
     app = MyApp()
     async with app.run_test() as pilot:
-        await pilot.click(Markdown, offset=(0, 0))
+        await pilot.click(Markdown, offset=(3, 0))
     assert links == ["tété"]
