@@ -8,6 +8,8 @@ from textual.events import (
     MouseDown,
     MouseMove,
     MouseScrollDown,
+    MouseScrollLeft,
+    MouseScrollRight,
     MouseScrollUp,
     MouseUp,
     Paste,
@@ -91,7 +93,7 @@ def test_cant_match_escape_sequence_too_long(parser):
     """The sequence did not match, and we hit the maximum sequence search
     length threshold, so each character should be issued as a key-press instead.
     """
-    sequence = "\x1b[123456789123456789123"
+    sequence = "\x1b[123456789123456789123123456789123456789123"
     events = list(parser.feed(sequence))
 
     # Every character in the sequence is converted to a key press
@@ -283,6 +285,56 @@ def test_mouse_scroll_down(parser, sequence, shift, meta):
     assert event.meta is meta
 
 
+@pytest.mark.parametrize(
+    "sequence, shift, meta",
+    [
+        ("\x1b[<66;18;25M", False, False),
+        ("\x1b[<70;18;25M", True, False),
+        ("\x1b[<74;18;25M", False, True),
+    ],
+)
+def test_mouse_scroll_left(parser, sequence, shift, meta):
+    """Scrolling the mouse with and without modifiers held down.
+    We don't currently capture modifier keys in scroll events.
+    """
+    events = list(parser.feed(sequence))
+
+    assert len(events) == 1
+
+    event = events[0]
+
+    assert isinstance(event, MouseScrollLeft)
+    assert event.x == 17
+    assert event.y == 24
+    assert event.shift is shift
+    assert event.meta is meta
+
+
+@pytest.mark.parametrize(
+    "sequence, shift, meta",
+    [
+        ("\x1b[<67;18;25M", False, False),
+        ("\x1b[<71;18;25M", True, False),
+        ("\x1b[<75;18;25M", False, True),
+    ],
+)
+def test_mouse_scroll_right(parser, sequence, shift, meta):
+    """Scrolling the mouse with and without modifiers held down.
+    We don't currently capture modifier keys in scroll events.
+    """
+    events = list(parser.feed(sequence))
+
+    assert len(events) == 1
+
+    event = events[0]
+
+    assert isinstance(event, MouseScrollRight)
+    assert event.x == 17
+    assert event.y == 24
+    assert event.shift is shift
+    assert event.meta is meta
+
+
 def test_mouse_event_detected_but_info_not_parsed(parser):
     # I don't know if this can actually happen in reality, but
     # there's a branch in the code that allows for the possibility.
@@ -299,8 +351,9 @@ def test_escape_sequence_resulting_in_multiple_keypresses(parser):
     assert events[1].key == "shift+insert"
 
 
-def test_terminal_mode_reporting_synchronized_output_supported(parser):
-    sequence = "\x1b[?2026;1$y"
+@pytest.mark.parametrize("parameter", range(1, 5))
+def test_terminal_mode_reporting_synchronized_output_supported(parser, parameter):
+    sequence = f"\x1b[?2026;{parameter}$y"
     events = list(parser.feed(sequence))
     assert len(events) == 1
     assert isinstance(events[0], TerminalSupportsSynchronizedOutput)
